import cntk as C
from cntkx.layers.models import VGG16, VGG19, UNET


def test_vgg16():
    a = C.input_variable((3, 64, 64))
    b = VGG16(100)(a)

    assert b.shape == (100, )


def test_vgg19():
    a = C.input_variable((3, 64, 64))
    b = VGG19(100)(a)

    assert b.shape == (100,)


def test_unet():
    a = C.input_variable((3, 128, 128))
    b = UNET(num_classes=10, base_num_filters=8, pad=True)(a)

    assert b.shape == (10, 128, 128)

    a = C.input_variable((3, 256, 256))
    b = UNET(num_classes=10, base_num_filters=2, pad=False)(a)
    # TODO: assert the shape with no padding



import cntk as C
from cntkx.learners import CyclicalLearningRate
import matplotlib.pyplot as plt


def test_clr():
    base_lr = 0.1
    max_lr = 1
    minibatch_size = 16
    step_size = 100

    a = C.input_variable(10)
    model = C.layers.Dense(10)(a)
    sgd = C.sgd(model.parameters, 0.01)
    clr = CyclicalLearningRate([sgd],
                               base_lrs=base_lr,
                               max_lrs=max_lr,
                               minibatch_size=minibatch_size,
                               step_size=step_size)
    lr_schedule = clr.get_lr_schedule()

    plt.scatter(range(lr_schedule.shape[0]), lr_schedule[:, 0], s=1)
    plt.show()
